# site-utils
<div class="markdown prose w-full break-words dark:prose-invert light"><p>Documentation for Site class:</p><p>The Site class provides static methods for retrieving and manipulating the content of a web page. It uses the node-fetch package to fetch the HTML content of a web page and the JSDOM package to create a virtual DOM object that can be manipulated with jQuery.</p><p>Methods:</p><ul><li><p><code>getWindow(domainURL: string): Promise&lt;Window&gt;</code>: This method takes a domain URL as input and returns a Promise that resolves to a Window object. The Window object is created from the HTML content of the web page using the JSDOM package. The Window object represents a virtual browser window that can be used to manipulate the content of the web page.</p></li><li><p><code>getDocument(domainURL: string): Promise&lt;Document&gt;</code>: This method takes a domain URL as input and returns a Promise that resolves to a Document object. The Document object is created from the HTML content of the web page using the JSDOM package. The Document object represents a virtual document object that can be used to manipulate the content of the web page.</p></li><li><p><code>get$(domainURL: string): Promise&lt;JQueryStatic&gt;</code>: This method takes a domain URL as input and returns a Promise that resolves to a jQuery object. The jQuery object is created from the Window object using the jQuery package. The jQuery object can be used to manipulate the content of the web page using jQuery syntax.</p></li></ul><p>Example usage:</p><pre><div class="bg-black rounded-md mb-4"><div class="flex items-center relative text-gray-200 bg-gray-800 px-4 py-2 text-xs font-sans justify-between rounded-t-md"></div><div class="p-4 overflow-y-auto"><code class="!whitespace-pre hljs language-javascript"><span class="hljs-keyword">import</span><span class="hljs-title class_"> { Site } </span><span class="hljs-keyword">from</span> <span class="hljs-string">"site-utils"</span>

<span class="hljs-comment">// get the document object for a web page</span>
<span class="hljs-keyword">const</span> document = <span class="hljs-keyword">await</span> <span class="hljs-title class_">Site</span>.<span class="hljs-title function_">getDocument</span>(<span class="hljs-string">"https://example.com"</span>)

<span class="hljs-comment">// get the jQuery object for a web page</span>
<span class="hljs-keyword">const</span> $ = <span class="hljs-keyword">await</span> <span class="hljs-title class_">Site</span>.<span class="hljs-title function_">get$</span>(<span class="hljs-string">"https://example.com"</span>)

<span class="hljs-comment">// use jQuery to manipulate the content of the web page</span>
$(<span class="hljs-string">"h1"</span>).<span class="hljs-title function_">text</span>(<span class="hljs-string">"Hello World!"</span>)
</code></div></div></pre><p>To use this package in your own project, you can install it from NPM using the following command:</p><pre><div class="bg-black rounded-md mb-4"><div class="flex items-center relative text-gray-200 bg-gray-800 px-4 py-2 text-xs font-sans justify-between rounded-t-md"></div><div class="p-4 overflow-y-auto"><code class="!whitespace-pre hljs">npm install site-utils
</code></div></div></pre><p>You can then import the Site class into your project and use its methods to manipulate the content of web pages.</p></div>
