/**
 * Provides methods for getting Images from URLs and HTML elements.
 */
export declare class GetImages {
    #private;
    /**
    * Constructor of GetImages class.
    * @param loggerConfig - (Optional) The configuration for logging.
    */
    constructor(loggerConfig?: LoggerConfigAddDuplicated);
    /**
     * Finds all the image elements in the provided HTML elements.
     * @param elements - The HTML elements to search for images in.
     * @returns An array of HTMLImageElement instances.
     */
    private findAllImages;
    /**
     * Retrieves image descriptors or image source URLs from the specified HTML content.
     * @param content The HTML content to search for images.
     * @param fileName Optional. If provided, only returns the unique image source URLs. Otherwise, returns the image descriptors.
     * @returns An array of ImageDescriptor objects if fileName is not provided, otherwise returns a set of unique image source URLs.
     */
    getImage(content: HTMLElement[], fileName?: undefined): Promise<ImageDescriptor[]>;
    getImage(content: HTMLElement[], fileName: string): Promise<Set<string>>;
    /**
     * Extracts image source URLs and their corresponding names (if available) from an array of HTML elements.
     * @param content - An array of HTML elements to search for images.
     * @returns An array of `ImageDescriptor` objects.
     * @throws An error if the `src` attribute value is not found.
     */
    private getImageDescriptors;
    /**
     * Extracts unique image source URLs from an array of HTML elements.
     * @param content - An array of HTML elements to search for images.
     * @returns A `Set` of unique image source URLs.
     * @throws An error if the `src` attribute value is not found.
     */
    private getImageSrces;
}
